@@ -1,6 +1,6 @@
 /*
  * Copyright © 2009 CNRS
- * Copyright © 2009-2016 Inria.  All rights reserved.
+ * Copyright © 2009-2018 Inria.  All rights reserved.
  * Copyright © 2009-2011 Université Bordeaux
  * Copyright © 2009-2011 Cisco Systems, Inc.  All rights reserved.
  * See COPYING in top-level directory.
@@ -222,7 +222,7 @@ hwloc__nolibxml_import_get_content(hwloc__xml_import_state_t state,
   if (nstate->closed) {
     if (expected_length)
       return -1;
-    *beginp = "";
+    *beginp = (char *) "";
     return 0;
   }
 
@@ -257,7 +257,7 @@ hwloc_nolibxml_look_init(struct hwloc_xml_backend_data_s *bdata,
   struct hwloc__nolibxml_backend_data_s *nbdata = bdata->data;
   char *buffer;
 
-  assert(sizeof(*nstate) <= sizeof(state->data));
+  HWLOC_BUILD_ASSERT(sizeof(*nstate) <= sizeof(state->data));
 
   /* use a copy in the temporary buffer, we may modify during parsing */
   buffer = nbdata->copy;
@@ -272,8 +272,17 @@ hwloc_nolibxml_look_init(struct hwloc_xml_backend_data_s *bdata,
   }
 
   /* find topology tag */
-  if (strncmp(buffer, "<topology>", 10))
+  if (strncmp(buffer, "<topology>", 10)) {
+    if (hwloc__xml_verbose()) {
+      if (!strncmp(buffer, "<topology version=", 18))
+	fprintf(stderr, "%s: hwloc v1.x cannot import topology version >= 2.\n",
+		state->global->msgprefix);
+      else
+	fprintf(stderr, "%s: failed to find starting tag <topology>\n",
+		state->global->msgprefix);
+    }
     goto failed;
+  }
 
   state->global->next_attr = hwloc__nolibxml_import_next_attr;
   state->global->find_child = hwloc__nolibxml_import_find_child;
@@ -295,9 +304,9 @@ hwloc_nolibxml_look_init(struct hwloc_xml_backend_data_s *bdata,
 static void
 hwloc_nolibxml_look_failed(struct hwloc_xml_backend_data_s *bdata __hwloc_attribute_unused)
 {
-  /* not only when verbose */
-  fprintf(stderr, "Failed to parse XML input with the minimalistic parser. If it was not\n"
-	  "generated by hwloc, try enabling full XML support with libxml2.\n");
+  if (hwloc__xml_verbose())
+    fprintf(stderr, "Failed to parse XML input with the minimalistic parser. If it was not\n"
+	    "generated by hwloc, try enabling full XML support with libxml2.\n");
 }
 
 /********************
@@ -423,7 +432,7 @@ hwloc_nolibxml_import_diff(struct hwloc__xml_import_state_s *state,
   size_t buflen;
   int ret;
 
-  assert(sizeof(*nstate) <= sizeof(state->data));
+  HWLOC_BUILD_ASSERT(sizeof(*nstate) <= sizeof(state->data));
 
   if (xmlbuffer) {
     buffer = malloc(xmlbuflen);
@@ -590,7 +599,7 @@ hwloc__nolibxml_export_new_child(hwloc__xml_export_state_t parentstate,
   ndata->nr_children = 0;
   ndata->has_content = 0;
 
-  res = hwloc_snprintf(ndata->buffer, ndata->remaining, "%*s<%s", npdata->indent, "", name);
+  res = hwloc_snprintf(ndata->buffer, ndata->remaining, "%*s<%s", (int) npdata->indent, "", name);
   hwloc__nolibxml_export_update_buffer(ndata, res);
 }
 
@@ -615,7 +624,7 @@ hwloc__nolibxml_export_end_object(hwloc__xml_export_state_t state, const char *n
   if (ndata->has_content) {
     res = hwloc_snprintf(ndata->buffer, ndata->remaining, "</%s>\n", name);
   } else if (ndata->nr_children) {
-    res = hwloc_snprintf(ndata->buffer, ndata->remaining, "%*s</%s>\n", npdata->indent, "", name);
+    res = hwloc_snprintf(ndata->buffer, ndata->remaining, "%*s</%s>\n", (int) npdata->indent, "", name);
   } else {
     res = hwloc_snprintf(ndata->buffer, ndata->remaining, "/>\n");
   }
@@ -650,7 +659,7 @@ hwloc___nolibxml_prepare_export(hwloc_topology_t topology, char *xmlbuffer, int
   hwloc__nolibxml_export_state_data_t ndata = (void *) &state.data;
   int res;
 
-  assert(sizeof(*ndata) <= sizeof(state.data));
+  HWLOC_BUILD_ASSERT(sizeof(*ndata) <= sizeof(state.data));
 
   state.new_child = hwloc__nolibxml_export_new_child;
   state.new_prop = hwloc__nolibxml_export_new_prop;
@@ -747,7 +756,7 @@ hwloc___nolibxml_prepare_export_diff(hwloc_topology_diff_t diff, const char *ref
   hwloc__nolibxml_export_state_data_t ndata = (void *) &state.data;
   int res;
 
-  assert(sizeof(*ndata) <= sizeof(state.data));
+  HWLOC_BUILD_ASSERT(sizeof(*ndata) <= sizeof(state.data));
 
   state.new_child = hwloc__nolibxml_export_new_child;
   state.new_prop = hwloc__nolibxml_export_new_prop;
